==> mesa-7.4.1-i486-1sys.tgz: usr/doc/mesa-7.4.1/configure.sh <==
# ##  Alles von Mesa* (Lib, Glut, Demos) zusammenkopieren und mesa nennen
# ## mit altem Paket vergleichen und fehlende Sachen kopieren -- etwa LIESMICH
# ## libdrm --> /usr/include/drm/<>_drm.h , /usr/lib/libdrm.* , /usr/include/xf86drm.h , mm.h  und
# ## glproto --> /usr/include/GL/glx*.h , glcore.h , internal    kopieren
#  ## /extra enthaelt:   a) /bin : ,
#  b) /etc/X11/xorg.conf  Beispiel fuer 3d Video config file (nvidia oder Radeon),
#  [c) /lib/usr link nach /usr -- gefaehrlich da systemweit]   d) in /usr/share:  ../maes3d/bin/images
#  /include, /usr/include , /lib/include , /extra/usr/include alles zusammenkopieren und ueberall hin, incl
#  in /usr/include eine Kopie von /lib/include   (aus mesa...tar.gz entzippt, enthaelt ../GL und GLview.h
#  Alle ../include ins lfnd. System kopieren, in /usr/include , damit beim comp. gefunden
# ## in /usr/include vom lfnd. System muessen stdio.h , stdarg.h , stddef.h vhd sein,
#  sonst von /usr/lib/gcc/i486-slackware-linux/<version>/include/ , ../ssp kopieren
#  ebenso limits.h wo das vom kernel/include zu nehmen ist (andere indirekt und problematisch)
# ## von mesa, libdrm, glproto  die install.sh  in jeweilige Ordner kopieren und ausführen sodas die
# links erzeugt werden, insb  libdrm.so -> .2 -> .2.3
# ## config in /configs/default machen, insbesondere:  INSTALL_DIR = /usr  und DRI_DRIVER_INST_DIR = /usr/lib/xorg/modules/dri
#  [/extra]/usr/share aus altem Paket kopieren.  ../usr/local/lib  nach ./usr/lib kopieren
# ##  In .auto.SlackBuild source-dir nicht saeubern lassen
#
#  Vor uebersetzen Unbedingt Kopie vom gesamten Ordner machen !!!!

make -i linux-dri-x86

# Alle Bibliotheken in lib bereinigen: strip --strip-unneeded *.so , Programme strip *
# in /extra/usr/lib und subdirs: alle links und doinst.sh genau so anpassen wie jetzt die Versions-Nrmn in ../lib  sind
# anschliessend:  Beispiele in /progs einzeln mit make -i  bersetzen ,  die besten davon (glxgears ...) nach extra/usr/bin kopieren 
# einen Ordner ~/extra machen, alles reinkopieren ausser der Dokumentation
# ./auto.SlackBuild:  source nicht lschen,  anwenden     (iW wird nur /extra kopiert)

#./auto.SlackBuild 

# ## Falls anschliessendes Umpacken der libs woanders hin, in pkgconf in den Dateien
#   Install-Pfade aendern



# Info:  mesa 7.4.1

# Sehr viele patchs noetig.  Insbesondere:
## In allen make-files  Eintragungen mit dylib loeschen bzw durch fruehere
##   make -files ersetzen
## Oft musste lib-insta--prefix explizit in makefiles geschrieben werden, 
##   da Ausdruecke mit " produziert wurden, die Probleme ergaben
## In /common/utils.c , glcontextmodes.c , clientattrib.c usw musste
##   GLcontextModus um nicht zugehoerige Elemente wie bindToTexturl.Rgb , .Rgba  
##   usw zu berrinigt werden,   usw usf

==> mesa-7.5-i486-1sys.tgz: usr/doc/mesa-7.5/configure.sh <==
# ##  Alles von Mesa* (Lib, Glut, Demos) zusammenkopieren und mesa nennen
# ## mit altem Paket vergleichen und fehlende Sachen kopieren -- etwa LIESMICH
# ## libdrm --> /usr/include/drm/<>_drm.h , /usr/include/xf86drm.h , mm.h , /usr/lib/libdrm.*  und
# ## glproto --> /usr/include/GL/glx*.h , glcore.h , internal    kopieren
#  ## /extra enthaelt:   a) /bin : ,
#  b) /etc/X11/xorg.conf  Beispiel fuer 3d Video config file (nvidia oder Radeon),
#  [c) /lib/usr link nach /usr -- gefaehrlich da systemweit]   d) in /usr/share:  ../mesa3d/bin/images
#  /include, /usr/include , /lib/include , /extra/usr/include alles zusammenkopieren und ueberall hin, incl
#  in /usr/include eine Kopie von /lib/include   (aus mesa...tar.gz entzippt, enthaelt ../GL und GLview.h
#  Alle ../include ins lfnd. System kopieren, in /usr/include , damit beim comp. gefunden
# ## in /usr/include vom lfnd. System muessen stdio.h , stdarg.h , stddef.h vhd sein,
#  sonst von /usr/lib/gcc/i486-slackware-linux/<version>/include/ , ../ssp kopieren
#  ebenso limits.h wo das vom kernel/include zu nehmen ist (andere indirekt und problematisch)
# ## von mesa, libdrm, glproto  die install.sh  in jeweilige Ordner kopieren und ausführen sodas die
# links erzeugt werden, insb  libdrm.so -> .2 -> .2.3
# ## config in /configs/default machen, insbesondere:  INSTALL_DIR = /usr  und DRI_DRIVER_INST_DIR = /usr/lib/xorg/modules/dri
#  [/extra]/usr/share aus altem Paket kopieren.  ../usr/local/lib  nach ./usr/lib kopieren
# ##  In .auto.SlackBuild source-dir nicht saeubern lassen
#
#  Vor uebersetzen Unbedingt Kopie vom gesamten Ordner machen !!!!

make -i linux-dri-x86

# Soweit erfolgreich uebersetzt, erneut Kopie des ganzen Ordners machen.
# Beispiele in /progs einzeln mit make -i  bersetzen , strippen,  die besten davon (glxgears ...) nach extra/usr/bin kopieren 
# Alle Bibliotheken in lib bereinigen: strip --strip-unneeded *.so , Programme strip *
# in /extra/usr/lib und subdirs: alle links und doinst.sh genau so anpassen wie jetzt die Versions-Nrmn in ../lib  sind
# einen Ordner ~/extra machen, alles reinkopieren ausser der Dokumentation
# Ab 7.4.4 sind libdrm und glxproto nicht mehr in mesa, daher ihre Dateien
#  NACH Uebersetzen in /extra/... loeschen
# ./auto.SlackBuild:  source nicht lschen,  anwenden     (iW wird nur /extra kopiert)

#./auto.SlackBuild 

# ## Falls anschliessendes Umpacken der libs woanders hin, in pkgconf in den Dateien
#   Install-Pfade aendern



# Info:  mesa 7.4.1

# Sehr viele patchs noetig.  Insbesondere:
## In allen make-files  Eintragungen mit dylib loeschen bzw durch fruehere
##   make -files ersetzen
## Oft musste lib-insta--prefix explizit in makefiles geschrieben werden, 
##   da Ausdruecke mit " produziert wurden, die Probleme ergaben
## In /common/utils.c , glcontextmodes.c , clientattrib.c usw musste
##   GLcontextModus um nicht zugehoerige Elemente wie bindToTexturl.Rgb , .Rgba  
##   usw zu berrinigt werden,   usw usf
